@@ -1345,7 +1345,10 @@ def csr_top(isa_yaml, grp_yaml, attr_yaml, aux_info, rvxlen, pkgname, logging =
     mod_attr_str = ''
     if 'minstret' in isa_yaml:
         if isa_yaml['minstret']['rv'+str(xlen)]['accessible']:
-            mod_attr_str = '(*conflict_free="ma_incr_minstret,sbread.mv_csr_minstret"*)'
+            mod_attr_str = '  (*conflict_free="ma_incr_minstret,sbread.mv_csr_minstret"*)'
+    if 'minstreth' in isa_yaml:
+        if isa_yaml['minstreth']['rv'+str(xlen)]['accessible']:
+            mod_attr_str += '\n  (*conflict_free="ma_incr_minstret,sbread.mv_csr_minstreth"*)'
     extra_reset = ''
     bsvstr += top_module_temp.format(pkgname,mod_attr_str, extra_reset) + '\n'
 
